@@ -29,6 +29,9 @@ FAILEDOPERATION_ASCOMMON = 'FailedOperation.AsCommon'
 # CLB 未知错误。
 FAILEDOPERATION_CLBUNEXPECTEDERROR = 'FailedOperation.CLBUnexpectedError'
 
+# CVM未知错误。
+FAILEDOPERATION_CVMUNEXPECTEDERROR = 'FailedOperation.CVMUnexpectedError'
+
 # 无该接口CAM权限。
 FAILEDOPERATION_CAMNOAUTH = 'FailedOperation.CamNoAuth'
 
@@ -53,6 +56,9 @@ FAILEDOPERATION_COMPONENTCLINETHTTP = 'FailedOperation.ComponentClinetHttp'
 # cvm创建节点报错。
 FAILEDOPERATION_CVMCOMMON = 'FailedOperation.CvmCommon'
 
+# 存在云服务器在CVM侧查询不到。
+FAILEDOPERATION_CVMNUMBERNOTMATCH = 'FailedOperation.CvmNumberNotMatch'
+
 # CVM 和 VPC ID 不匹配。
 FAILEDOPERATION_CVMVPCIDNOTMATCH = 'FailedOperation.CvmVpcidNotMatch'
 
@@ -107,6 +113,12 @@ FAILEDOPERATION_TASKALREADYRUNNING = 'FailedOperation.TaskAlreadyRunning'
 # 询价错误。
 FAILEDOPERATION_TRADECOMMON = 'FailedOperation.TradeCommon'
 
+# VPC未知错误。
+FAILEDOPERATION_VPCUNEXPECTEDERROR = 'FailedOperation.VPCUnexpectedError'
+
+# VPC报错。
+FAILEDOPERATION_VPCCOMMON = 'FailedOperation.VpcCommon'
+
 # 未发现vpc记录。
 FAILEDOPERATION_VPCRECODRNOTFOUND = 'FailedOperation.VpcRecodrNotFound'
 
@@ -236,6 +248,9 @@ INTERNALERROR_KUBERNETESGETOPERATIONERROR = 'InternalError.KubernetesGetOperatio
 # Kubernetes未知错误。
 INTERNALERROR_KUBERNETESINTERNAL = 'InternalError.KubernetesInternal'
 
+# Kubernetes Patch操作失败。
+INTERNALERROR_KUBERNETESPATCHOPERATIONERROR = 'InternalError.KubernetesPatchOperationError'
+
 # 底层调用CLB未知错误。
 INTERNALERROR_LBCOMMON = 'InternalError.LbCommon'
 
@@ -308,6 +323,9 @@ INTERNALERROR_VPCPEERNOTFOUND = 'InternalError.VpcPeerNotFound'
 # 未发现vpc记录。
 INTERNALERROR_VPCRECODRNOTFOUND = 'InternalError.VpcRecodrNotFound'
 
+# VstationError。
+INTERNALERROR_VSTATIONERROR = 'InternalError.VstationError'
+
 # 白名单未知错误。
 INTERNALERROR_WHITELISTUNEXPECTEDERROR = 'InternalError.WhitelistUnexpectedError'
 
@@ -332,6 +350,9 @@ INVALIDPARAMETER_CIDRCONFLICTWITHVPCCIDR = 'InvalidParameter.CidrConflictWithVpc
 # 创建的路由与VPC下已存在的全局路由产生冲突。
 INVALIDPARAMETER_CIDRCONFLICTWITHVPCGLOBALROUTE = 'InvalidParameter.CidrConflictWithVpcGlobalRoute'
 
+# CIDR无效。
+INVALIDPARAMETER_CIDRINVALI = 'InvalidParameter.CidrInvali'
+
 # 参数错误，CIDR不符合规范。
 INVALIDPARAMETER_CIDRINVALID = 'InvalidParameter.CidrInvalid'
 
